==> haskell-cryptohash-md5-0.11.100.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-md5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-md5
version: 0.11.100.1
id: cryptohash-md5-0.11.100.1-9Crf9wW9dLGV2WJt31xcX
key: cryptohash-md5-0.11.100.1-9Crf9wW9dLGV2WJt31xcX
license: BSD3
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-md5
synopsis: Fast, pure and practical MD5 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/MD5 MD5 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package
    has been deprecated and so this package continues to satisfy the need for a lightweight package
    providing the MD5 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.MD5" module, though with a clearly smaller footprint.
category: Data, Cryptography
exposed: True
exposed-modules:
    Crypto.Hash.MD5
abi: 76dbd1e7062e12cf135114747a13ce90
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-md5-0.11.100.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-md5-0.11.100.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptohash-md5-0.11.100.1
hs-libraries: HScryptohash-md5-0.11.100.1-9Crf9wW9dLGV2WJt31xcX
depends:
    base-4.9.0.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-cryptohash-md5/html/cryptohash-md5.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-md5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-md5-0.11.100.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-md5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-md5
version: 0.11.100.1
id: cryptohash-md5-0.11.100.1-L0CJbuRTZmBI8mOB7huEe7
key: cryptohash-md5-0.11.100.1-L0CJbuRTZmBI8mOB7huEe7
license: BSD3
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-md5
synopsis: Fast, pure and practical MD5 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/MD5 MD5 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package
    has been deprecated and so this package continues to satisfy the need for a lightweight package
    providing the MD5 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.MD5" module, though with a clearly smaller footprint.
category: Data, Cryptography
exposed: True
exposed-modules:
    Crypto.Hash.MD5
abi: caa819792708cdc12533a82ce7f5cf08
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cryptohash-md5-0.11.100.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/cryptohash-md5-0.11.100.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/cryptohash-md5-0.11.100.1
hs-libraries: HScryptohash-md5-0.11.100.1-L0CJbuRTZmBI8mOB7huEe7
depends:
    base-4.9.1.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-cryptohash-md5/html/cryptohash-md5.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-md5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
